Re-exports
Modules
Macros
Structs
- Agent
Lock - Global mutability lock for all SW-Agents
- Agent
Runtime - Code
Store - Storage for our webassembly code
- Contract
Lock - Global mutability lock for all contracts
- Contract
Runtime
Constants
- ACTION_
TX_ REL_ SUB_ DB - Sub-Database to store the relationship between an action and a transaction
- AGENT_
SUB_ DB - Sub-Database for all agent related data
- CONTRACT_
SUB_ DB - Sub-Database for all contract related data
- LEDGER_
SUB_ DB - Sub-Database, where the ledger information is stored
- SUBSCRIPTION_
REL_ SUB_ DB - Sub-Database to store the relationship between contracts and agents, and vice-versa
- WASM_
CODE_ SUB_ DB - Sub-Database, where the wasm code is stored