Struct Runtime

pub struct Runtime<S = Lmdb>
where S: Db,
{ /* private fields */ }

Implementations

Source

impl<S: Db> Runtime<S>

pub fn new( storage: &S, agent_store: CodeStore<S>, lock: MutLock, ) -> Result<Self>

pub fn into_shared(self) -> Arc<Mutex<Self>>

pub fn instantiate_sw_agent( &mut self, agent_id: AgentId, module_bytes: &[u8], ) -> Result<()>

pub fn set_executor(&mut self, executor_id: BorderlessId) -> Result<()>

Sets the currently active executor

This writes the BorderlessId of the executor to the dedicated register, so that the wasm side can query it.

pub fn register_ws(&mut self, aid: AgentId) -> Result<Receiver<Vec<u8>>>

Registers a new websocket client

pub async fn initialize(&mut self, aid: &AgentId) -> Result<Init>

pub async fn process_ws_msg( &mut self, aid: &AgentId, msg: Vec<u8>, ) -> Result<Option<Events>>

pub async fn on_ws_open(&mut self, aid: &AgentId) -> Result<Option<Events>>

pub async fn on_ws_error(&mut self, aid: &AgentId) -> Result<Option<Events>>

pub async fn on_ws_close(&mut self, aid: &AgentId) -> Result<Option<Events>>

pub async fn process_introduction( &mut self, introduction: Introduction, ) -> Result<()>

pub async fn process_revocation(&mut self, revocation: Revocation) -> Result<()>

pub async fn process_action( &mut self, aid: &AgentId, action: CallAction, ) -> Result<Option<Events>>

pub async fn http_get_state( &mut self, aid: &AgentId, path: String, ) -> Result<(u16, Vec<u8>)>

pub async fn http_post_action( &mut self, aid: &AgentId, path: String, payload: Vec<u8>, writer: &BorderlessId, ) -> Result<Result<(Events, CallAction), (u16, String)>>

Uses a POST request to parse and generate a CallAction object.

The return type is a nested result. The outer result type should convert to a server error, as it represents errors in the runtime itself. The inner error type comes from the wasm code and contains the error status and message.

pub async fn get_symbols(&mut self, aid: &AgentId) -> Result<Option<Symbols>>

Returns the symbols of the contract

pub fn available_agents(&self) -> Result<Vec<AgentId>>