Struct Runtime

pub struct Runtime<S = Lmdb>
where S: Db,
{ /* private fields */ }

Implementations

Source

impl<S: Db> Runtime<S>

pub fn new( storage: &S, contract_store: CodeStore<S>, lock: MutLock, ) -> Result<Self>

pub fn into_shared(self) -> Arc<Mutex<Self>>

pub fn instantiate_contract( &mut self, contract_id: ContractId, module_bytes: &[u8], ) -> Result<()>

Creates a new instance of the wasm module in our CodeStore for the given contract-id

pub fn set_block( &mut self, block_id: BlockIdentifier, block_timestamp: u64, ) -> Result<()>

Sets the currently active block

This writes the BlockCtx to the dedicated register, so that the wasm side can query it.

pub fn set_executor(&mut self, executor_id: BorderlessId) -> Result<()>

Sets the currently active executor

This writes the BorderlessId of the executor to the dedicated register, so that the wasm side can query it.

pub fn process_transaction( &mut self, cid: &ContractId, action: CallAction, writer: &BorderlessId, tx_ctx: TxCtx, ) -> Result<Option<Events>>

pub fn process_introduction( &mut self, introduction: Introduction, writer: &BorderlessId, tx_ctx: TxCtx, ) -> Result<()>

pub fn process_revocation( &mut self, revocation: Revocation, writer: &BorderlessId, tx_ctx: TxCtx, ) -> Result<()>

pub fn perform_dry_run( &mut self, cid: &ContractId, action: &CallAction, writer: &BorderlessId, ) -> Result<()>

Executes an action without commiting the state

pub fn http_get_state( &mut self, cid: &ContractId, path: String, ) -> Result<(u16, Vec<u8>)>

pub fn http_post_action( &mut self, cid: &ContractId, path: String, payload: Vec<u8>, writer: &BorderlessId, ) -> Result<Result<CallAction, (u16, String)>>

Uses a POST request to parse and generate a CallAction object.

The return type is a nested result. The outer result type should convert to a server error, as it represents errors in the runtime itself. The inner error type comes from the wasm code and contains the error status and message.

pub fn get_symbols(&mut self, cid: &ContractId) -> Result<Option<Symbols>>

Returns the symbols of the contract

pub fn read_action( &self, cid: &ContractId, idx: usize, ) -> Result<Option<ActionRecord>>

pub fn len_actions(&self, cid: &ContractId) -> Result<u64>

pub fn available_contracts(&self) -> Result<Vec<ContractId>>