ActionLog

Struct ActionLog 

pub struct ActionLog<'a, S: Db> { /* private fields */ }
The ActionLog records all actions that were successfully executed by the contract.

Since the action is fed into the contract as json-encoded bytes, we record exactly the raw json-bytes here, and not the CallAction object. This allows us to efficiently give out the json object, because instead of deserializing and then serializing it back to json, we can directly copy the json data after deserialization.

Implementations

Source

impl<'a, S: Db> ActionLog<'a, S>

pub fn new(db: &'a S, cid: ContractId) -> Self

Opens (or creates) the action log

pub fn get(&self, idx: usize) -> Result<Option<ActionRecord>>

Retrieves a value from the log

pub fn get_tx_action_paginated( &self, pagination: Pagination, ) -> Result<Option<PaginatedElements<TxAction>>>

pub fn last(&self) -> Result<Option<ActionRecord>>

Retrieves the last action record

pub fn len(&self) -> Result<u64>

pub fn is_empty(&self) -> Result<bool>

pub fn iter(&self) -> Iter<'_, S>

Returns an iterator over all action-records