pub struct RelTxAction {
pub cid: ContractId,
pub action_idx: u64,
}Expand description
Relationship between an action and a transaction
This model is saved behind the key of a tx-identifier, to be able to relate a transaction back to the action.
Fields
cid: ContractIdContract-ID of the action’s contract
action_idx: u64Index (number) of the action inside the contract
Implementations
Sourceimpl RelTxAction
impl RelTxAction
Sourcepub fn into_bytes(self) -> [u8; 24]
pub fn into_bytes(self) -> [u8; 24]
Converts the RelTxAction into bytes
Sourcepub fn from_bytes(bytes: &[u8]) -> Self
pub fn from_bytes(bytes: &[u8]) -> Self
Parses the relation from bytes
Panics
This function panics, if the byte-slice is not an encoded RelTxAction object.