Controller

Struct Controller 

pub struct Controller<'a, S: Db> { /* private fields */ }
Model-controller to retrieve information about a contract from the key-value storage.

Implementations

Source

impl<'a, S: Db> Controller<'a, S>

pub fn new(db: &'a S) -> Self

pub fn actions(&self, cid: ContractId) -> ActionLog<'a, S>

Returns the ActionLog of the contract

pub fn logs(&self, id: impl Into<Id>) -> Logger<'a, S>

Returns the Logger of the contract or agent

pub fn ledger(&self) -> Ledger<'a, S>

Returns the Ledger

pub fn messages(&self) -> SubscriptionHandler<'a, S>

Returns the [‘SubscriptionHandler’]

pub fn contract_participants( &self, cid: &ContractId, ) -> Result<Option<Vec<Participant>>>

List of contract-participants

pub fn contract_exists(&self, cid: &ContractId) -> Result<bool>

Returns true if the contract exists

pub fn agent_exists(&self, aid: &AgentId) -> Result<bool>

Returns true if the contract exists

pub fn contract_revoked(&self, cid: &ContractId) -> Result<bool>

Returns true if the contract has been revoked

pub fn agent_revoked(&self, aid: &AgentId) -> Result<bool>

Returns true if the agent has been revoked

pub fn contract_revoked_ts(&self, cid: &ContractId) -> Result<Option<u64>>

Returns the timestamp, when the contract has been revoked.

pub fn agent_revoked_ts(&self, aid: &AgentId) -> Result<Option<u64>>

Returns the timestamp, when the agent has been revoked.

pub fn contract_last_tx_hash(&self, cid: &ContractId) -> Result<Option<Hash256>>

Returns the hash of the last-tx that was executed by the contract

pub fn contract_info(&self, cid: &ContractId) -> Result<Option<Info>>

Returns the Info section of the contract

pub fn agent_sinks(&self, aid: &AgentId) -> Result<Option<Vec<Sink>>>

Returns the sinks for an agent

Since an agent has no participants of roles, the sinks and the agent-id are the only two things that are left from the Info struct.

pub fn agent_subs(&self, aid: &AgentId) -> Result<Vec<Topic>>

pub fn contract_desc(&self, cid: &ContractId) -> Result<Option<Description>>

Returns the Description of the contract

pub fn agent_desc(&self, aid: &AgentId) -> Result<Option<Description>>

Returns the Description of the agent

pub fn contract_meta(&self, cid: &ContractId) -> Result<Option<Metadata>>

Returns the Metadata of the contract

pub fn agent_meta(&self, aid: &AgentId) -> Result<Option<Metadata>>

Returns the Metadata of the agent

pub fn contract_full(&self, cid: &ContractId) -> Result<Option<ContractInfo>>

Returns the full ContractInfo, which bundles info, description and metadata.

pub fn agent_full(&self, aid: &AgentId) -> Result<Option<AgentInfo>>

Returns the full AgentInfo, which bundles info, description and metadata.

pub fn contract_revocation( &self, cid: &ContractId, ) -> Result<Option<Revocation>>

Returns the Revocation of the contract, if any.

pub fn agent_revocation(&self, aid: &AgentId) -> Result<Option<Revocation>>

Returns the Revocation of the contract, if any.

pub fn query_action(&self, tx_id: &TxIdentifier) -> Result<Option<ActionRecord>>

Queries an ActionRecord based on the TxIdentifier

pub fn agent_pkg_def(&self, aid: &AgentId) -> Result<Option<WasmPkgNoSource>>

Returns the package definition for an agent

pub fn agent_pkg_source(&self, aid: &AgentId) -> Result<Option<Source>>

Returns the package definition for an agent

pub fn agent_pkg_full(&self, aid: &AgentId) -> Result<Option<WasmPkg>>

Returns the package definition for an agent

pub fn contract_pkg_def( &self, aid: &ContractId, ) -> Result<Option<WasmPkgNoSource>>

Returns the package definition for an contract

pub fn contract_pkg_source(&self, aid: &ContractId) -> Result<Option<Source>>

Returns the package definition for an contract

pub fn contract_pkg_full(&self, aid: &ContractId) -> Result<Option<WasmPkg>>

Returns the package definition for an contract

pub fn filter_events(&self, events: Events) -> Result<Events>

Filters a set of events, discarding those considered invalid

Events considered invalid are:

  • [‘ContractCall’] targeting a non-existing SmartContract
  • [‘ContractCall’] targeting a revoked SmartContract
  • [‘Message’] with no subscribers

Returns a new [‘Events’] containing only the valid events