pub struct LedgerMeta {
pub creditor: BorderlessId,
pub debitor: BorderlessId,
pub len: u64,
pub balances: HashMap<Currency, i64>,
}Expand description
Meta information about this ledger
Fields
creditor: BorderlessIdCreditor side
debitor: BorderlessIdDebitor side
len: u64Length of the ledger
balances: HashMap<Currency, i64>Balances by currency ( values are in 1000 units, so 1€ = 1000 )
Implementations
Sourceimpl LedgerMeta
impl LedgerMeta
pub fn new(creditor: BorderlessId, debitor: BorderlessId) -> Self
pub fn into_dto(self) -> LedgerMetaDto
Sourcepub fn reset_balance(&mut self)
pub fn reset_balance(&mut self)
Resets the balances and length - useful when creating a temporary balance from the original LedgerMeta
Sourcepub fn update(&mut self, entry: &LedgerEntry) -> Result<()>
pub fn update(&mut self, entry: &LedgerEntry) -> Result<()>
Updates the ledger meta information with the current entry
Returns an error, if the ledger-entry does not belong to this ledger.