pub struct RtFactory<'a, S: Db> { /* private fields */ }Expand description
Create new runtimes with shared code-store, cache and lock.
This factory is capable of spawning agent runtimes and contract runtimes.
The agent and contract runtimes spawned by this factory have a shared CodeStore,
but their individual execution locks (there is one lock for all agents and one lock for all contracts).
Implementations
Sourceimpl<'a, S: Db> RtFactory<'a, S>
impl<'a, S: Db> RtFactory<'a, S>
Sourcepub fn with_store(db: &'a S, code_store: CodeStore<S>) -> Self
pub fn with_store(db: &'a S, code_store: CodeStore<S>) -> Self
Creates a new over an existing code store
Sourcepub fn set_cache_size(&mut self, cache_size: NonZeroUsize) -> Result<()>
pub fn set_cache_size(&mut self, cache_size: NonZeroUsize) -> Result<()>
Sets the cache size and initializes the code-store
Panic
This function will panic, if the code-store has already been initialized.
Sourcepub fn spawn_contract_rt(&mut self) -> Result<ContractRuntime<S>>
pub fn spawn_contract_rt(&mut self) -> Result<ContractRuntime<S>>
Creates a new contract runtime
Sourcepub fn spawn_agent_rt(&mut self) -> Result<AgentRuntime<S>>
pub fn spawn_agent_rt(&mut self) -> Result<AgentRuntime<S>>
Creates a new agent runtime