Struct AgentLock

pub struct AgentLock { /* private fields */ }
Global mutability lock for all SW-Agents

Since we can only allow one mutable agent execution at a given time, we need a mechanism to ensure that. The MutLock ensures this on a per-agent basis. It holds RwLocks for all agents and provides threadsafe access.

The logic is similar but not identical to rusts ownership rules. While there can be only one read-write (mutable) execution, there can be multiple read-only (immutable) executions even if there is an ongoing read-write execution ! The reason behind this is basically that read-only executions do not produce storage operations that would change the state in the database. In the VmState, all write operations are buffered until the execution is finished. If there would be two executions in parallel, we might end up commiting changes to a state, that has already changed under the hood - which is not what we want. However, if there is a writer thread, the readers do not care, and also the writer does not care about the readers. The readers will use the old state, until the new one is commited by the runtime.

Note: In contrast to [borderless_runtime::rt::contract::MutLock], this version uses asynchronous locks for the agents, and a synchronous lock only for the access of the hashmap.

Additionally, this double-functions as the provider of over-arching state per agent, e.g. the lock also contains the websocket sender, for agents that use websockets.

Implementations

Source

impl MutLock

pub fn get_lock_state(&self, aid: &AgentId) -> Lock

Returns the RwLock for the given agent.

If the agent-id is unknown, a new lock is created.

pub fn insert_ws_sender(&self, aid: &AgentId, ws_sender: Sender<Vec<u8>>)

Inserts a new ws-sender for the agent

Panics if the sender already contained a lock