Crate borderless_runtime

Re-exports

pub use error::Error;
pub use error::Result;

Modules

agent
code_store
contract
db
error
factory
http

Macros

void

Structs

AgentLock
Global mutability lock for all SW-Agents
AgentRuntime
CodeStore
Storage for our webassembly code
ContractLock
Global mutability lock for all contracts
ContractRuntime

Constants

ACTION_TX_REL_SUB_DB
Sub-Database to store the relationship between an action and a transaction
AGENT_SUB_DB
Sub-Database for all agent related data
CONTRACT_SUB_DB
Sub-Database for all contract related data
LEDGER_SUB_DB
Sub-Database, where the ledger information is stored
SUBSCRIPTION_REL_SUB_DB
Sub-Database to store the relationship between contracts and agents, and vice-versa
WASM_CODE_SUB_DB
Sub-Database, where the wasm code is stored

Type Aliases

SharedAgentRuntime
SharedContractRuntime