Module action_log

Structs

ActionLog
The ActionLog records all actions that were successfully executed by the contract.
ActionRecord
The ActionRecord is used to record actions in the ActionLog.
Iter
Iterator over the ActionLog
RelTxAction
Relationship between an action and a transaction

Constants

SUB_KEY_LOG_LEN
Sub-Key where the length of the action-log is stored