pub struct ActionLog<'a, S: Db> { /* private fields */ }Expand description
The ActionLog records all actions that were successfully executed by the contract.
Since the action is fed into the contract as json-encoded bytes, we record exactly the raw json-bytes here,
and not the CallAction object. This allows us to efficiently give out the json object,
because instead of deserializing and then serializing it back to json, we can directly copy the json data after deserialization.
Implementations
Sourceimpl<'a, S: Db> ActionLog<'a, S>
impl<'a, S: Db> ActionLog<'a, S>
Sourcepub fn new(db: &'a S, cid: ContractId) -> Self
pub fn new(db: &'a S, cid: ContractId) -> Self
Opens (or creates) the action log
pub fn get_tx_action_paginated( &self, pagination: Pagination, ) -> Result<Option<PaginatedElements<TxAction>>>
Sourcepub fn last(&self) -> Result<Option<ActionRecord>>
pub fn last(&self) -> Result<Option<ActionRecord>>
Retrieves the last action record
pub fn len(&self) -> Result<u64>
pub fn is_empty(&self) -> Result<bool>