pub struct ActionRecord {
pub tx_ctx: TxCtx,
pub value: Vec<u8>,
pub commited: u64,
}Expand description
The ActionRecord is used to record actions in the ActionLog.
The record bundles the raw json-bytes of the action together with meta-information like the transaction identifier and transaction sequence number (which is the index of the transaction inside the block).
Fields
tx_ctx: TxCtxvalue: Vec<u8>Action value as raw bytes.
Since all incoming events are encoded in json, we directly save the json bytes here. This enables us to later directly spit out the json (for usage via api e.g.) without having to serialize it back.
Note: This must decode to a CallAction object.
commited: u64Timestamp (as milliseconds since unix-epoch), when the action was commited.